==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/src/Uncertainty/Algorithm/Analytical/FORM/FORM.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  FORM.cxx
 *  @brief FORM implements the First Order Reliability Method
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-09-13 22:37:56 +0200 (sam 13 sep 2008) $
 *  Id:      $Id: FORM.cxx 929 2008-09-13 20:37:56Z dutka $
 */
#include "FORM.hxx"

namespace OpenTURNS
{

  namespace Uncertainty
  {

    namespace Algorithm
    {

      CLASSNAMEINIT(FORM);

      /*
       * @brief  Standard constructor: the class is defined by an optimisation algorithm, a failure event and a physical starting point
       */
      FORM::FORM(const NearestPointAlgorithm & nearestPointAlgorithm,
		 const Event & event,
		 const NumericalPoint & physicalStartingPoint):
	Analytical(nearestPointAlgorithm, event, physicalStartingPoint)
      {
	// Nothing to do
      }

      /* Virtual constructor */
      FORM * FORM::clone() const
      {
	return new FORM(*this);
      }

      /* Result accessor */
      FORMResult FORM::getResult() const
      {
	return result_;
      }

      /* Result accessor */
      void FORM::setResult(const FORMResult & result)
      {
	result_ = result;
      }


      /* String converter */ 
      String FORM::str() const
      {   
	OSS oss;
	oss << "class=" << FORM::GetClassName()
            << " " << Analytical::str()
            << " result=" << result_;
	return oss;
      }

      /* Function that computes the design point by re-using the Analytical::run() and creates a FORMResult */
      void FORM::run()
      {
	Analytical::run();
	result_ = FORMResult(Analytical::getAnalyticalResult().getStandardSpaceDesignPoint(), Analytical::getAnalyticalResult().getLimitStateVariable(), Analytical::getAnalyticalResult().getIsStandardPointOriginInFailureSpace());
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

==> openturns_0.13.1.orig.tar.gz: openturns-0.13.1/lib/src/Uncertainty/Algorithm/Analytical/FORM/FORM.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  FORM.cxx
 *  @brief FORM implements the First Order Reliability Method
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009) $
 *  Id:      $Id: FORM.cxx 1262 2009-05-28 12:47:53Z dutka $
 */
#include "FORM.hxx"

namespace OpenTURNS
{

  namespace Uncertainty
  {

    namespace Algorithm
    {

      CLASSNAMEINIT(FORM);

      /*
       * @brief  Standard constructor: the class is defined by an optimisation algorithm, a failure event and a physical starting point
       */
      FORM::FORM(const NearestPointAlgorithm & nearestPointAlgorithm,
		 const Event & event,
		 const NumericalPoint & physicalStartingPoint):
	Analytical(nearestPointAlgorithm, event, physicalStartingPoint)
      {
	// Nothing to do
      }

      /* Virtual constructor */
      FORM * FORM::clone() const
      {
	return new FORM(*this);
      }

      /* Result accessor */
      FORMResult FORM::getResult() const
      {
	return result_;
      }

      /* Result accessor */
      void FORM::setResult(const FORMResult & result)
      {
	result_ = result;
      }


      /* String converter */ 
      String FORM::__repr__() const
      {   
	OSS oss;
	oss << "class=" << FORM::GetClassName()
            << " " << Analytical::__repr__()
            << " result=" << result_;
	return oss;
      }

      /* Function that computes the design point by re-using the Analytical::run() and creates a FORMResult */
      void FORM::run()
      {
	Analytical::run();
	result_ = FORMResult(Analytical::getAnalyticalResult().getStandardSpaceDesignPoint(), Analytical::getAnalyticalResult().getLimitStateVariable(), Analytical::getAnalyticalResult().getIsStandardPointOriginInFailureSpace());
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
